#
# spec file for package novprog
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2016 Graeme Gott <graeme@gottcode.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           novprog
Version:        3.2.3
Release:        1.5
Summary:        Wordcount graphing program
License:        GPL-3.0-or-later
Group:          Productivity/Office/Other
URL:            https://gottcode.org/novprog/
Source:         https://gottcode.org/novprog/download/?os=source#/%{name}-%{version}-src.tar.bz2
BuildRequires:  cmake
%if 0%{?suse_version} < 1550
BuildRequires:  gcc11-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  qt6-linguist-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt6Core)
BuildRequires:  pkgconfig(Qt6Gui)
BuildRequires:  pkgconfig(Qt6Widgets)
BuildRequires:  pkgconfig(opengl)
BuildRequires:  pkgconfig(xkbcommon) >= 0.5.0
Requires:       hicolor-icon-theme

%description
NovProg allows you to create a graph of your progress in writing a
NaNoWriMo style novel. You enter your wordcount and it updates a graph
showing you how much progress you have made. It also shows you how far you
are through your daily goal, and your total goal. Mousing over a bar in the
graph will show a tooltip with that day's wordcount.

%lang_package

%prep
%autosetup

%build
%if 0%{?suse_version} < 1550
export CXX=g++-11
%endif
%cmake
%cmake_build

%install
%cmake_install
%suse_update_desktop_file -u -r %{name} Office Publishing
%find_lang %{name} --with-qt

%files
%license COPYING
%doc ChangeLog CREDITS README
%{_bindir}/%{name}
%dir %{_datadir}/%{name}
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/novprog.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*
%{_mandir}/man1/%{name}.1%{?ext_man}

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations

%changelog
* Fri Feb  2 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.2.3:
  * Replaced deprecated code
  * Translation updates: Turkish
* Tue Jun 20 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.2.2:
  * Improved Linux deployment
  * Replaced deprecated code
- Changes for version 3.2.1:
  * Switched to Qt 6
* Thu Dec  9 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.2.0:
  * Added setting words written for current day
  * Added support for Qt 6
  * Refactored code
  * Removed XPM icon
  * Translation updates: Dutch, Lithuanian
* Fri Apr 24 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.1.7:
  * FIXED: Did not load locales with underscores
  * Improved Windows deployment
  * Replaced deprecated code
- Changes in version 3.1.6:
  * FIXED: Window icon didn't work in Wayland
  * Improved loading locales
  * Improved Windows deployment
  * Replaced deprecated code
* Wed Nov 21 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.1.5:
  * FIXED: Automatic high DPI support
- Changes for version 3.1.4:
  * Extra warnings only shown in debug build
  * Translation updates: Portuguese
- Mark license as such
* Wed Nov 21 2018 Karol Babioch <kbabioch@suse.de>
- Update to version 3.1.5
  * FIXED: Automatic high DPI support
- Update to version 3.1.4
  * Extra warnings only shown in debug build
  * Improved Linux deployment
  * Improved macOS deployment
  * Improved Windows deployment
  * Translation updates: Portuguese
- Applied spec-cleaner
* Mon Jan  8 2018 mpluskal@suse.com
- Update to verion 3.1.3:
  * FIXED: Could not compile with Qt 5.10.
  * Translation updates: French.
- Do not run post scriplets on Tumbleweed where they are not needed
- Split lang subpackage
* Thu Oct 19 2017 mpluskal@suse.com
- Update to version 3.1.2:
  * FIXED: Did not always install translations in Linux.
  * Translation updates: Dutch.
* Fri Dec 23 2016 mpluskal@suse.com
- Update to version 3.1.1:
  * Generate binary translations at build time.
  * FIXED: Was not properly loading Qt translations.
  * Translation updates: Dutch, Lithuanian.
* Sat May 14 2016 mpluskal@suse.com
- Package for 3.1.0 (based on spec file by Graeme Gott)
